Summary: A firewall daemon with D-Bus interface providing a dynamic firewall
Name: firewalld
Version: 2.2.1
Release: %mkrel 1
Group: System/Servers
License: GPLv2+
URL: https://www.firewalld.org
Source0: https://github.com/firewalld/firewalld/releases/download/v%{version}/firewalld-%{version}.tar.gz
BuildArch: noarch
BuildRequires: autoconf
BuildRequires: automake
BuildRequires: desktop-file-utils
BuildRequires: gettext
BuildRequires: intltool
# glib2-devel is needed for gsettings.m4
BuildRequires: glib2-devel
BuildRequires: systemd-units
BuildRequires: docbook-style-xsl
BuildRequires: libxslt
BuildRequires: iptables, ebtables, ipset
BuildRequires: python3-devel
BuildRequires: make
Requires: iptables, ebtables, ipset
Suggests: iptables-nft
%{?systemd_requires}
Requires: firewalld-filesystem = %{version}-%{release}
Requires: python3-firewall  = %{version}-%{release}
Recommends: libcap-ng-python3

%description
firewalld is a firewall service daemon that provides a dynamic customizable 
firewall with a D-Bus interface.

%package -n python3-firewall
Summary: Python3 bindings for firewalld
Group: Development/Python

%{?python_provide:%python_provide python3-firewall}

Requires: python3-dbus
Requires: python3-gobject-base
Requires: python3-nftables

%description -n python3-firewall
Python3 bindings for firewalld.

%package -n firewalld-filesystem
Summary: Firewalld directory layout and rpm macros
Group: System/Servers

%description -n firewalld-filesystem
This package provides directories and rpm macros which
are required by other packages that add firewalld configuration files.

%package -n firewalld-testsuite
Summary: Firewalld testsuite
Group: System/Servers

%description -n firewalld-testsuite
This package provides the firewalld testsuite.

%package -n firewall-applet
Summary: Firewall panel applet
Group: System/Servers
Requires: %{name} = %{version}-%{release}
Requires: firewall-config = %{version}-%{release}
Requires: python3-qt5-core
Requires: python3-qt5-gui
Requires: python3-qt5-widgets
Requires: python3-gobject
Requires: libnotify
Requires: dbus-x11

%description -n firewall-applet
The firewall panel applet provides a status information of firewalld and also
the firewall settings.

%package -n firewall-config
Summary: Firewall configuration application
Group: System/Servers
Requires: %{name} = %{version}-%{release}
Requires: python3-gobject
Requires: dbus-x11
Recommends: polkit

%description -n firewall-config
The firewall configuration application provides a configuration interface for
firewalld.

%prep
%autosetup -p1

./autogen.sh

%build
%configure --enable-sysconfig --enable-rpmmacros PYTHON="%{__python3} %{py3_shbang_opts}"
%make_build

%install
%make_install

desktop-file-install --delete-original \
  --dir %{buildroot}%{_sysconfdir}/xdg/autostart \
  %{buildroot}%{_sysconfdir}/xdg/autostart/firewall-applet.desktop
desktop-file-install --delete-original \
  --dir %{buildroot}%{_datadir}/applications \
  %{buildroot}%{_datadir}/applications/firewall-config.desktop

%find_lang %{name} --all-name

# Move modprobe.d config to /usr/lib
mv %{buildroot}%{_sysconfdir}/modprobe.d %{buildroot}%{_prefix}/lib

%post
%systemd_post firewalld.service

%preun
%systemd_preun firewalld.service

%postun
%systemd_postun_with_restart firewalld.service


%files -f %{name}.lang
%license COPYING
%doc README.md
%{_sbindir}/firewalld
%{_bindir}/firewall-cmd
%{_bindir}/firewall-offline-cmd
%{_datadir}/bash-completion/completions/firewall-cmd
%{_datadir}/zsh/site-functions/_firewalld
%{_prefix}/lib/firewalld/icmptypes/*.xml
%{_prefix}/lib/firewalld/ipsets/README.md
%{_prefix}/lib/firewalld/policies/*.xml
%{_prefix}/lib/firewalld/services/*.xml
%{_prefix}/lib/firewalld/zones/*.xml
%{_prefix}/lib/firewalld/helpers/*.xml
%{_prefix}/lib/firewalld/xmlschema/check.sh
%{_prefix}/lib/firewalld/xmlschema/*.xsd
%attr(0750,root,root) %dir %{_sysconfdir}/firewalld
%config(noreplace) %{_sysconfdir}/firewalld/firewalld.conf
%attr(0750,root,root) %dir %{_sysconfdir}/firewalld/helpers
%attr(0750,root,root) %dir %{_sysconfdir}/firewalld/icmptypes
%attr(0750,root,root) %dir %{_sysconfdir}/firewalld/ipsets
%attr(0750,root,root) %dir %{_sysconfdir}/firewalld/policies
%attr(0750,root,root) %dir %{_sysconfdir}/firewalld/services
%attr(0750,root,root) %dir %{_sysconfdir}/firewalld/zones
%config(noreplace) %{_sysconfdir}/sysconfig/firewalld
%{_unitdir}/firewalld.service
%config(noreplace) %{_datadir}/dbus-1/system.d/FirewallD.conf
%{_datadir}/polkit-1/actions/org.fedoraproject.FirewallD1.desktop.policy.choice
%{_datadir}/polkit-1/actions/org.fedoraproject.FirewallD1.server.policy.choice
%{_datadir}/polkit-1/actions/org.fedoraproject.FirewallD1.policy
%{_mandir}/man1/firewall*cmd*.1*
%{_mandir}/man1/firewalld*.1*
%{_mandir}/man5/firewall*.5*
%{_prefix}/lib/modprobe.d/firewalld-sysctls.conf
%{_sysconfdir}/logrotate.d/firewalld
 
%files -n python3-firewall
%attr(0755,root,root) %dir %{python3_sitelib}/firewall
%attr(0755,root,root) %dir %{python3_sitelib}/firewall/__pycache__
%attr(0755,root,root) %dir %{python3_sitelib}/firewall/config
%attr(0755,root,root) %dir %{python3_sitelib}/firewall/config/__pycache__
%attr(0755,root,root) %dir %{python3_sitelib}/firewall/core
%attr(0755,root,root) %dir %{python3_sitelib}/firewall/core/__pycache__
%attr(0755,root,root) %dir %{python3_sitelib}/firewall/core/io
%attr(0755,root,root) %dir %{python3_sitelib}/firewall/core/io/__pycache__
%attr(0755,root,root) %dir %{python3_sitelib}/firewall/server
%attr(0755,root,root) %dir %{python3_sitelib}/firewall/server/__pycache__
%{python3_sitelib}/firewall/__pycache__/*.py*
%{python3_sitelib}/firewall/*.py*
%{python3_sitelib}/firewall/config/*.py*
%{python3_sitelib}/firewall/config/__pycache__/*.py*
%{python3_sitelib}/firewall/core/*.py*
%{python3_sitelib}/firewall/core/__pycache__/*.py*
%{python3_sitelib}/firewall/core/io/*.py*
%{python3_sitelib}/firewall/core/io/__pycache__/*.py*
%{python3_sitelib}/firewall/server/*.py*
%{python3_sitelib}/firewall/server/__pycache__/*.py*

%files -n firewalld-filesystem
%dir %{_prefix}/lib/firewalld
%dir %{_prefix}/lib/firewalld/helpers
%dir %{_prefix}/lib/firewalld/icmptypes
%dir %{_prefix}/lib/firewalld/ipsets
%dir %{_prefix}/lib/firewalld/policies
%dir %{_prefix}/lib/firewalld/services
%dir %{_prefix}/lib/firewalld/zones
%{_rpmconfigdir}/macros.d/macros.firewalld

%files -n firewalld-testsuite
%{_datadir}/firewalld/testsuite/

%files -n firewall-applet
%{_bindir}/firewall-applet
%{_sysconfdir}/xdg/autostart/firewall-applet.desktop
%dir %{_sysconfdir}/firewall
%{_sysconfdir}/firewall/applet.conf
%{_datadir}/icons/hicolor/*/apps/firewall-applet*.*
%{_mandir}/man1/firewall-applet*.1*

%files -n firewall-config
%{_bindir}/firewall-config
%{_datadir}/firewalld/firewall-config.glade
%{_datadir}/firewalld/gtk3_chooserbutton.py*
%{_datadir}/firewalld/gtk3_niceexpander.py*
%{_datadir}/applications/firewall-config.desktop
%{_metainfodir}/firewall-config.appdata.xml
%{_datadir}/icons/hicolor/*/apps/firewall-config*.*
%{_datadir}/glib-2.0/schemas/org.fedoraproject.FirewallConfig.gschema.xml
%{_mandir}/man1/firewall-config*.1*


%changelog
* Tue Aug 27 2024 neoclust <neoclust> 2.2.1-1.mga10
+ Revision: 2091679
- New version 2.2.1

* Fri Dec 29 2023 papoteur <papoteur> 1.3.0-3.mga10
+ Revision: 2024203
- rebuild again for python 3.12

* Sat Dec 09 2023 wally <wally> 1.3.0-2.mga10
+ Revision: 2016162
- rebuild for py3.12

* Wed Jan 18 2023 wally <wally> 1.3.0-1.mga9
+ Revision: 1934347
- new version 1.3.0

* Mon Dec 12 2022 daviddavid <daviddavid> 1.2.2-1.mga9
+ Revision: 1921193
- new version: 1.2.2

* Thu Oct 06 2022 neoclust <neoclust> 1.2.1-1.mga9
+ Revision: 1895036
- New version 1.2.1

* Wed Aug 03 2022 neoclust <neoclust> 1.2.0-1.mga9
+ Revision: 1874987
- New version 1.2.0

* Tue Mar 29 2022 umeabot <umeabot> 0.9.3-4.mga9
+ Revision: 1831659
- Mageia 9 Mass Rebuild

* Tue Feb 22 2022 tv <tv> 0.9.3-3.mga9
+ Revision: 1782848
- Rebuild for python-3.10

* Mon Mar 22 2021 neoclust <neoclust> 0.9.3-2.mga9
+ Revision: 1707792
- Rebuild against python 3.9

* Sun Feb 28 2021 daviddavid <daviddavid> 0.9.3-1.mga9
+ Revision: 1694390
- new version: 0.9.3

* Thu Oct 08 2020 daviddavid <daviddavid> 0.9.1-1.mga8
+ Revision: 1632770
- new version: 0.9.1

* Thu Sep 03 2020 daviddavid <daviddavid> 0.9.0-1.mga8
+ Revision: 1621191
- new version: 0.9.0

* Fri Jul 03 2020 daviddavid <daviddavid> 0.8.3-1.mga8
+ Revision: 1601519
- new version: 0.8.3

* Thu Apr 02 2020 daviddavid <daviddavid> 0.8.2-1.mga8
+ Revision: 1564063
- new version: 0.8.2

* Fri Feb 21 2020 umeabot <umeabot> 0.8.1-2.mga8
+ Revision: 1547784
- Mageia 8 Mass Rebuild

* Mon Feb 10 2020 daviddavid <daviddavid> 0.8.1-1.mga8
+ Revision: 1488340
- new version: 0.8.1
+ wally <wally>
- replace deprecated %%configure2_5x

* Wed Nov 06 2019 daviddavid <daviddavid> 0.8.0-1.mga8
+ Revision: 1458547
- new version: 0.8.0

* Sun Oct 13 2019 daviddavid <daviddavid> 0.7.2-1.mga8
+ Revision: 1452605
- new version: 0.7.2

* Sun Sep 15 2019 daviddavid <daviddavid> 0.6.3-2.mga8
+ Revision: 1441702
- rebuild for python3.8

* Sat Feb 23 2019 ngompa <ngompa> 0.6.3-1.mga7
+ Revision: 1369539
- Rebase to 0.6.3

* Tue Jan 08 2019 shlomif <shlomif> 0.4.4.3-8.mga7
+ Revision: 1352788
- Rebuild for python3 3.7

* Thu Sep 20 2018 umeabot <umeabot> 0.4.4.3-7.mga7
+ Revision: 1278238
- Mageia 7 Mass Rebuild

* Tue Aug 07 2018 wally <wally> 0.4.4.3-6.mga7
+ Revision: 1248829
- add pycache back

* Fri Jul 06 2018 daviddavid <daviddavid> 0.4.4.3-5.mga7
+ Revision: 1242172
- update files list (no more __pycache__ reference)

* Sat Aug 05 2017 pterjan <pterjan> 0.4.4.3-4.mga7
+ Revision: 1135210
- Rebuild for python 3.6

* Fri Feb 17 2017 neoclust <neoclust> 0.4.4.3-3.mga6
+ Revision: 1086601
- add more strict python3-qt5-<module> requires for applet (thx to wally)

* Fri Feb 17 2017 neoclust <neoclust> 0.4.4.3-2.mga6
+ Revision: 1086600
- Add python3-qt5 as applet requires (thx to wally)

* Fri Feb 17 2017 neoclust <neoclust> 0.4.4.3-1.mga6
+ Revision: 1086560
- New version 0.4.4.3

* Mon Feb 13 2017 neoclust <neoclust> 0.4.4.2-1.mga6
+ Revision: 1086032
- imported package firewalld

